@@ -113,6 +113,9 @@ INVALIDPARAMETER_CNAMEWILDHOSTNOTALLOWAPPLYCERTIFICATE = 'InvalidParameter.Cname
 # 域名不存在或不属于该账号。
 INVALIDPARAMETER_DOMAINNOTFOUND = 'InvalidParameter.DomainNotFound'
 
+# 当前域名已开启流量调度功能。
+INVALIDPARAMETER_DOMAINONTRAFFICSCHEDULING = 'InvalidParameter.DomainOnTrafficScheduling'
+
 # 操作不支持条件。
 INVALIDPARAMETER_ERRACTIONUNSUPPORTTARGET = 'InvalidParameter.ErrActionUnsupportTarget'
 
@@ -359,6 +362,9 @@ RESOURCEINUSE_CNAME = 'ResourceInUse.Cname'
 # Dns资源被占用。
 RESOURCEINUSE_DNS = 'ResourceInUse.Dns'
 
+# 该域名正在解析中，如果您需要开启加速，请前往 DNS 记录页开启加速。
+RESOURCEINUSE_DNSRECORD = 'ResourceInUse.DnsRecord'
+
 # 已存在相同的别称域名。
 RESOURCEINUSE_DUPLICATENAME = 'ResourceInUse.DuplicateName'
 
